.. _user_guide-name:

!!!!!!!!!!
user_guide
!!!!!!!!!!

.. meta::
   :keywords: user_guide, extract, sphinx, rst, files

.. index:: user_guide, extract, sphinx, rst, files

.. _user_guide-title:

Extract Sphinx RST Files
########################

.. contents::
   :local:

.. meta::
   :keywords: git, repository

.. index:: git, repository

.. _user_guide@Git Repository:

Git Repository
**************
`<https://github.com/bradbell/xrst>`_

.. meta::
   :keywords: version, documentation

.. index:: version, documentation

.. _user_guide@Version of this Documentation:

Version of this Documentation
*****************************
xrst-2023.0.1

.. meta::
   :keywords: install, stable, version

.. index:: install, stable, version

.. _user_guide@Install Stable Version:

Install Stable Version
**********************
::

   pip install xrst

.. meta::
   :keywords: install, testing, version

.. index:: install, testing, version

.. _user_guide@Install Testing Version:

Install Testing Version
***********************
::

   pip install --index-url https://test.pypi.org/simple/ xrst

.. meta::
   :keywords: run, program

.. index:: run, program

.. _user_guide@Run Program:

Run Program
***********
:ref:`run_xrst-title`

.. meta::
   :keywords: contents

.. index:: contents

.. _user_guide@Contents:

Contents
********

-  :ref:`config_file-title`
-  :ref:`run_xrst-title`
-  :ref:`commands-title`
-  :ref:`automatic-title`
-  :ref:`wish_list-title`
-  :ref:`release_notes-title`

.. toctree::
   :maxdepth: 1
   :hidden:

   config_file
   run_xrst
   commands
   automatic
   wish_list
   release_notes
